@@ -1,10 +1,19 @@
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 from contextlib import contextmanager
 
 from .file import H5File
 
 
 @contextmanager
-def open_h5file(filename, mode='r+', **kwargs):
+def open_h5file(filename, mode="r+", **kwargs):
     """Context manager for reading an HDF5 file as an H5File object.
 
     Parameters
