@@ -1,16 +1,12 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2005, Enthought, Inc.
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-# Thanks for using Enthought open source!
 #
-# Author: Enthought, Inc.
-# Description: <Enthought naming package component>
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 """ The base class for all object serializers. """
 
 
@@ -18,11 +14,10 @@
 import logging
 from traceback import print_exc
 from os.path import splitext
-#import cPickle
-#import pickle
+import pickle
 
 # Enthought library imports.
-import apptools.sweet_pickle as sweet_pickle
+from apptools.persistence.versioned_unpickler import VersionedUnpickler
 from traits.api import HasTraits, Str
 
 
@@ -36,7 +31,7 @@ class ObjectSerializer(HasTraits):
     #### 'ObjectSerializer' interface #########################################
 
     # The file extension recognized by this serializer.
-    ext = Str('.pickle')
+    ext = Str(".pickle")
 
     ###########################################################################
     # 'ObjectSerializer' interface.
@@ -53,15 +48,15 @@ class ObjectSerializer(HasTraits):
         """ Loads an object from a file. """
 
         # Unpickle the object.
-        f = open(path, 'rb')
+        f = open(path, "rb")
         try:
             try:
-                 obj = sweet_pickle.load(f)
-#                obj = cPickle.load(f)
-#                obj = pickle.load(f)
-            except Exception, ex:
+                obj = VersionedUnpickler(f).load()
+            except Exception as ex:
                 print_exc()
-                logger.exception( "Failed to load pickle file: %s, %s" % (path, ex))
+                logger.exception(
+                    "Failed to load pickle file: %s, %s" % (path, ex)
+                )
 
                 raise
         finally:
@@ -84,17 +79,15 @@ class ObjectSerializer(HasTraits):
             actual_path = path
 
         # Pickle the object.
-        f = open(actual_path, 'wb')
+        f = open(actual_path, "wb")
         try:
-            sweet_pickle.dump(obj, f, 1)
-#            cPickle.dump(obj, f, 1)
-#            pickle.dump(obj, f, 1)
-        except Exception, ex:
-            logger.exception( "Failed to pickle into file: %s, %s, object:%s"
-                % (path, ex, obj))
+            pickle.dump(obj, f, 1)
+        except Exception as ex:
+            logger.exception(
+                "Failed to pickle into file: %s, %s, object:%s"
+                % (path, ex, obj)
+            )
             print_exc()
         f.close()
 
         return actual_path
-
-### EOF #######################################################################
