@@ -1,3 +1,12 @@
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 """ A page in a preferences dialog. """
 
 
@@ -6,15 +15,13 @@ from apptools.preferences.api import PreferencesHelper
 from traits.api import Any, Dict, Str, provides
 
 # Local imports.
-from i_preferences_page import IPreferencesPage
+from .i_preferences_page import IPreferencesPage
 
 
 @provides(IPreferencesPage)
 class PreferencesPage(PreferencesHelper):
     """ A page in a preferences dialog. """
 
-
-
     #### 'IPreferencesPage' interface #########################################
 
     # The page's category (e.g. 'General/Appearance'). The empty string means
@@ -53,32 +60,10 @@ class PreferencesPage(PreferencesHelper):
 
         for trait_name, value in self._changed.items():
             if self._is_preference_trait(trait_name):
-                self.preferences.set('%s.%s' % (path, trait_name), value)
+                self.preferences.set("%s.%s" % (path, trait_name), value)
 
         self._changed.clear()
 
-        return
-
-    # fixme: We would like to be able to have the following API so that
-    # developers are not forced into using traits UI for their preferences
-    # pages, but at the moment I can't work out how to do it!
-##     def create_control(self, parent):
-##         """ Create the toolkit-specific control that represents the page. """
-
-##         if self._ui is None:
-##             self._ui = self.edit_traits(parent=parent, kind='subpanel')
-
-##         return self._ui.control
-
-##     def destroy_control(self):
-##         """ Destroy the toolkit-specific control that represents the page. """
-
-##         if self._ui is not None:
-##             self._ui.dispose()
-##             self._ui = None
-
-##         return
-
     ###########################################################################
     # Private interface.
     ###########################################################################
@@ -86,7 +71,7 @@ class PreferencesPage(PreferencesHelper):
     #### Trait change handlers ################################################
 
     def _anytrait_changed(self, trait_name, old, new):
-        """ Static trait change handler.
+        """Static trait change handler.
 
         This is an important override! In the base-class when a trait is
         changed the preferences node is updated too. Here, we stop that from
@@ -95,27 +80,25 @@ class PreferencesPage(PreferencesHelper):
 
         """
 
-        # If the trait was a list or dict '_items' trait then just treat it as
-        # if the entire list or dict was changed.
-        if trait_name.endswith('_items'):
+        if self._is_preference_trait(trait_name):
+            self._changed[trait_name] = new
+        elif trait_name.endswith("_items"):
+            # If the trait was a list or dict '_items' trait then just treat it
+            # as if the entire list or dict was changed.
             trait_name = trait_name[:-6]
             if self._is_preference_trait(trait_name):
                 self._changed[trait_name] = getattr(self, trait_name)
 
-        elif self._is_preference_trait(trait_name):
-            self._changed[trait_name] = new
-
-        return
-
     # fixme: Pretty much duplicated in 'PreferencesHelper' (except for the
     # class name of course!).
     def _is_preference_trait(self, trait_name):
         """ Return True if a trait represents a preference value. """
 
-        if trait_name.startswith('_') or trait_name.endswith('_') \
-           or trait_name in PreferencesPage.class_traits():
+        if (
+            trait_name.startswith("_")
+            or trait_name.endswith("_")
+            or trait_name in PreferencesPage.class_traits()
+        ):
             return False
 
-        return True
-
-#### EOF ######################################################################
+        return trait_name in self.editable_traits()
