@@ -1,19 +1,25 @@
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 """
 A Recorder subclass that presents a simple user interface.
 """
-# Author: Prabhu Ramachandran <prabhu@aero.iitb.ac.in>
-# Copyright (c) 2008, Prabhu Ramachandran.
-# License: BSD Style.
 
-from traits.api import Code, Button, Int, on_trait_change, Any
-from traitsui.api import (View, Item, Group, HGroup, CodeEditor,
-                                     spring, Handler)
+from traits.api import Code, Button, Int, observe, Any
+from traitsui.api import View, Item, Group, HGroup, CodeEditor, spring, Handler
 
 from .recorder import Recorder
 
-######################################################################
+
+###############################################################################
 # `CloseHandler` class.
-######################################################################
+###############################################################################
 class CloseHandler(Handler):
     """This class cleans up after the UI for the recorder is closed."""
 
@@ -24,19 +30,19 @@ class CloseHandler(Handler):
         return True
 
 
-################################################################################
+###############################################################################
 # `RecorderWithUI` class.
-################################################################################
+###############################################################################
 class RecorderWithUI(Recorder):
     """
     This class represents a Recorder but with a simple user interface.
     """
 
     # The code to display
-    code = Code(editor=CodeEditor(line='current_line'))
+    code = Code(editor=CodeEditor(line="current_line"))
 
     # Button to save script to file.
-    save_script = Button('Save Script')
+    save_script = Button("Save Script")
 
     # The current line to show, used by the editor.
     current_line = Int
@@ -47,20 +53,21 @@ class RecorderWithUI(Recorder):
     ########################################
     # Traits View.
     view = View(
-             Group(
-                HGroup(Item('recording', show_label=True),
-                       spring,
-                       Item('save_script', show_label=False),
-                ),
-                Group(Item('code', show_label=False)),
-                ),
-             width=600,
-             height=360,
-             id='apptools.scripting.recorder_with_ui',
-             buttons=['Cancel'],
-             resizable=True,
-             handler=CloseHandler()
-             )
+        Group(
+            HGroup(
+                Item("recording", show_label=True),
+                spring,
+                Item("save_script", show_label=False),
+            ),
+            Group(Item("code", show_label=False)),
+        ),
+        width=600,
+        height=360,
+        id="apptools.scripting.recorder_with_ui",
+        buttons=["Cancel"],
+        resizable=True,
+        handler=CloseHandler(),
+    )
 
     ######################################################################
     # RecorderWithUI interface.
@@ -69,8 +76,8 @@ class RecorderWithUI(Recorder):
         """Called from the CloseHandler when the UI is closed. This
         method basically stops the recording.
         """
-        from util import stop_recording
-        from package_globals import get_recorder
+        from .util import stop_recording
+        from .package_globals import get_recorder
 
         if get_recorder() is self:
             stop_recording(self.root, save=False)
@@ -81,8 +88,8 @@ class RecorderWithUI(Recorder):
     ######################################################################
     # Non-public interface.
     ######################################################################
-    @on_trait_change('lines[]')
-    def _update_code(self):
+    @observe("lines.items")
+    def _update_code(self, event):
         self.code = self.get_code()
         self.current_line = len(self.lines) + 1
 
